import compression from 'compression';
import * as sapper from '@sapper/server';
import { createConnection, getRepository, getConnectionOptions } from "typeorm";
import express from "express";
import dotenv from "dotenv";
import { KnownUser } from "@db/entity/KnownUser";
import { DB_ENTITIES } from "@db/entities";

if(process.env.NODE_ENV == "development") {
	console.log(process.cwd());
    dotenv.config({
        path: "../.env"
    });
    dotenv.config({
        path: "../db.env"
    });
    process.env.TYPEORM_HOST = "localhost";
    process.env.TYPEORM_USERNAME = process.env.DB_USERNAME;
    process.env.TYPEORM_PASSWORD = process.env.DB_PASSWORD;
	process.env.TYPEORM_DATABASE = process.env.DB_NAME;
}


const PORT = +(process.env.PORT as string);
async function main() {
	await createConnection({
		...await getConnectionOptions(),
		entities: DB_ENTITIES
	});

	let repo = getRepository(KnownUser);

	let first = await repo.findOne();

	if(first)
		console.log(`Got user ${first} with ID ${first.userID}`);
	else
		console.log(`No user found!`);

	express()
		.use(
			compression({ threshold: 0 }),
			express.static("static"),
			sapper.middleware()
		)
		.listen(PORT, err => {
			if (err) console.log('error', err);
		});
}

main();

